@@ -58,6 +58,8 @@ from google.cloud.datastream_v1.types.datastream import (
 from google.cloud.datastream_v1.types.datastream_resources import (
     AvroFileFormat,
     BackfillJob,
+    BigQueryDestinationConfig,
+    BigQueryProfile,
     ConnectionProfile,
     DestinationConfig,
     Error,
@@ -78,6 +80,12 @@ from google.cloud.datastream_v1.types.datastream_resources import (
     OracleSchema,
     OracleSourceConfig,
     OracleTable,
+    PostgresqlColumn,
+    PostgresqlProfile,
+    PostgresqlRdbms,
+    PostgresqlSchema,
+    PostgresqlSourceConfig,
+    PostgresqlTable,
     PrivateConnection,
     PrivateConnectivity,
     Route,
@@ -132,6 +140,8 @@ __all__ = (
     "UpdateStreamRequest",
     "AvroFileFormat",
     "BackfillJob",
+    "BigQueryDestinationConfig",
+    "BigQueryProfile",
     "ConnectionProfile",
     "DestinationConfig",
     "Error",
@@ -152,6 +162,12 @@ __all__ = (
     "OracleSchema",
     "OracleSourceConfig",
     "OracleTable",
+    "PostgresqlColumn",
+    "PostgresqlProfile",
+    "PostgresqlRdbms",
+    "PostgresqlSchema",
+    "PostgresqlSourceConfig",
+    "PostgresqlTable",
     "PrivateConnection",
     "PrivateConnectivity",
     "Route",
