@@ -53,6 +53,8 @@ from .datastream import (
 from .datastream_resources import (
     AvroFileFormat,
     BackfillJob,
+    BigQueryDestinationConfig,
+    BigQueryProfile,
     ConnectionProfile,
     DestinationConfig,
     Error,
@@ -73,6 +75,12 @@ from .datastream_resources import (
     OracleSchema,
     OracleSourceConfig,
     OracleTable,
+    PostgresqlColumn,
+    PostgresqlProfile,
+    PostgresqlRdbms,
+    PostgresqlSchema,
+    PostgresqlSourceConfig,
+    PostgresqlTable,
     PrivateConnection,
     PrivateConnectivity,
     Route,
@@ -125,6 +133,8 @@ __all__ = (
     "UpdateStreamRequest",
     "AvroFileFormat",
     "BackfillJob",
+    "BigQueryDestinationConfig",
+    "BigQueryProfile",
     "ConnectionProfile",
     "DestinationConfig",
     "Error",
@@ -145,6 +155,12 @@ __all__ = (
     "OracleSchema",
     "OracleSourceConfig",
     "OracleTable",
+    "PostgresqlColumn",
+    "PostgresqlProfile",
+    "PostgresqlRdbms",
+    "PostgresqlSchema",
+    "PostgresqlSourceConfig",
+    "PostgresqlTable",
     "PrivateConnection",
     "PrivateConnectivity",
     "Route",
