@@ -104,6 +104,11 @@ class DiscoverConnectionProfileRequest(proto.Message):
             MySQL RDBMS to enrich with child data objects
             and metadata.
 
+            This field is a member of `oneof`_ ``data_object``.
+        postgresql_rdbms (google.cloud.datastream_v1.types.PostgresqlRdbms):
+            PostgreSQL RDBMS to enrich with child data
+            objects and metadata.
+
             This field is a member of `oneof`_ ``data_object``.
     """
 
@@ -144,6 +149,12 @@ class DiscoverConnectionProfileRequest(proto.Message):
         oneof="data_object",
         message=datastream_resources.MysqlRdbms,
     )
+    postgresql_rdbms = proto.Field(
+        proto.MESSAGE,
+        number=102,
+        oneof="data_object",
+        message=datastream_resources.PostgresqlRdbms,
+    )
 
 
 class DiscoverConnectionProfileResponse(proto.Message):
@@ -164,6 +175,10 @@ class DiscoverConnectionProfileResponse(proto.Message):
         mysql_rdbms (google.cloud.datastream_v1.types.MysqlRdbms):
             Enriched MySQL RDBMS object.
 
+            This field is a member of `oneof`_ ``data_object``.
+        postgresql_rdbms (google.cloud.datastream_v1.types.PostgresqlRdbms):
+            Enriched PostgreSQL RDBMS object.
+
             This field is a member of `oneof`_ ``data_object``.
     """
 
@@ -179,6 +194,12 @@ class DiscoverConnectionProfileResponse(proto.Message):
         oneof="data_object",
         message=datastream_resources.MysqlRdbms,
     )
+    postgresql_rdbms = proto.Field(
+        proto.MESSAGE,
+        number=102,
+        oneof="data_object",
+        message=datastream_resources.PostgresqlRdbms,
+    )
 
 
 class FetchStaticIpsRequest(proto.Message):
