@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,15 +33,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.datastream_v1alpha1.services.datastream import pagers
-from google.cloud.datastream_v1alpha1.types import datastream
-from google.cloud.datastream_v1alpha1.types import datastream_resources
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import DatastreamTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import DatastreamGrpcAsyncIOTransport
+
+from google.cloud.datastream_v1alpha1.services.datastream import pagers
+from google.cloud.datastream_v1alpha1.types import datastream, datastream_resources
+
 from .client import DatastreamClient
+from .transports.base import DEFAULT_CLIENT_INFO, DatastreamTransport
+from .transports.grpc_asyncio import DatastreamGrpcAsyncIOTransport
 
 
 class DatastreamAsyncClient:
@@ -224,14 +225,13 @@ class DatastreamAsyncClient:
         r"""Use this method to list connection profiles created
         in a project and location.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_list_connection_profiles():
+            async def sample_list_connection_profiles():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.ListConnectionProfilesRequest(
@@ -242,7 +242,7 @@ class DatastreamAsyncClient:
                 page_result = client.list_connection_profiles(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -300,12 +300,20 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListConnectionProfilesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -323,14 +331,13 @@ class DatastreamAsyncClient:
         r"""Use this method to get details about a connection
         profile.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_get_connection_profile():
+            async def sample_get_connection_profile():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.GetConnectionProfileRequest(
@@ -338,7 +345,7 @@ class DatastreamAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_connection_profile(request=request)
+                response = await client.get_connection_profile(request=request)
 
                 # Handle the response
                 print(response)
@@ -395,7 +402,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -414,14 +426,13 @@ class DatastreamAsyncClient:
         r"""Use this method to create a connection profile in a
         project and location.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_create_connection_profile():
+            async def sample_create_connection_profile():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 connection_profile = datastream_v1alpha1.ConnectionProfile()
@@ -442,7 +453,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -521,7 +532,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -547,14 +563,13 @@ class DatastreamAsyncClient:
         r"""Use this method to update the parameters of a
         connection profile.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_update_connection_profile():
+            async def sample_update_connection_profile():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 connection_profile = datastream_v1alpha1.ConnectionProfile()
@@ -573,7 +588,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -650,7 +665,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -678,9 +698,9 @@ class DatastreamAsyncClient:
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_delete_connection_profile():
+            async def sample_delete_connection_profile():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.DeleteConnectionProfileRequest(
@@ -692,7 +712,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -728,9 +748,6 @@ class DatastreamAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -764,7 +781,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -791,14 +813,13 @@ class DatastreamAsyncClient:
         returns children data objects under a parent data object
         that's optionally supplied in the request.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_discover_connection_profile():
+            async def sample_discover_connection_profile():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 connection_profile = datastream_v1alpha1.ConnectionProfile()
@@ -815,7 +836,7 @@ class DatastreamAsyncClient:
                 )
 
                 # Make the request
-                response = client.discover_connection_profile(request=request)
+                response = await client.discover_connection_profile(request=request)
 
                 # Handle the response
                 print(response)
@@ -852,7 +873,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -869,14 +895,13 @@ class DatastreamAsyncClient:
         r"""Use this method to list streams in a project and
         location.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_list_streams():
+            async def sample_list_streams():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.ListStreamsRequest(
@@ -887,7 +912,7 @@ class DatastreamAsyncClient:
                 page_result = client.list_streams(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -945,12 +970,20 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListStreamsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -971,9 +1004,9 @@ class DatastreamAsyncClient:
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_get_stream():
+            async def sample_get_stream():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.GetStreamRequest(
@@ -981,7 +1014,7 @@ class DatastreamAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_stream(request=request)
+                response = await client.get_stream(request=request)
 
                 # Handle the response
                 print(response)
@@ -1038,7 +1071,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1060,9 +1098,9 @@ class DatastreamAsyncClient:
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_create_stream():
+            async def sample_create_stream():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 stream = datastream_v1alpha1.Stream()
@@ -1081,7 +1119,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1158,7 +1196,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1184,14 +1227,13 @@ class DatastreamAsyncClient:
         r"""Use this method to update the configuration of a
         stream.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_update_stream():
+            async def sample_update_stream():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 stream = datastream_v1alpha1.Stream()
@@ -1208,7 +1250,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1284,7 +1326,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1312,9 +1359,9 @@ class DatastreamAsyncClient:
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_delete_stream():
+            async def sample_delete_stream():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.DeleteStreamRequest(
@@ -1326,7 +1373,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1362,9 +1409,6 @@ class DatastreamAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1398,7 +1442,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1422,14 +1471,13 @@ class DatastreamAsyncClient:
         r"""Use this method to fetch any errors associated with a
         stream.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_fetch_errors():
+            async def sample_fetch_errors():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.FetchErrorsRequest(
@@ -1440,7 +1488,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1482,7 +1530,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1509,14 +1562,13 @@ class DatastreamAsyncClient:
         children data objects under a parent data object that's
         optionally supplied in the request.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_fetch_static_ips():
+            async def sample_fetch_static_ips():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.FetchStaticIpsRequest(
@@ -1527,7 +1579,7 @@ class DatastreamAsyncClient:
                 page_result = client.fetch_static_ips(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1588,12 +1640,20 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.FetchStaticIpsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1613,14 +1673,13 @@ class DatastreamAsyncClient:
         r"""Use this method to create a private connectivity
         configuration.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_create_private_connection():
+            async def sample_create_private_connection():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 private_connection = datastream_v1alpha1.PrivateConnection()
@@ -1637,7 +1696,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1716,7 +1775,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1741,14 +1805,13 @@ class DatastreamAsyncClient:
         r"""Use this method to get details about a private
         connectivity configuration.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_get_private_connection():
+            async def sample_get_private_connection():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.GetPrivateConnectionRequest(
@@ -1756,7 +1819,7 @@ class DatastreamAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_private_connection(request=request)
+                response = await client.get_private_connection(request=request)
 
                 # Handle the response
                 print(response)
@@ -1817,7 +1880,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1834,14 +1902,13 @@ class DatastreamAsyncClient:
         r"""Use this method to list private connectivity
         configurations in a project and location.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_list_private_connections():
+            async def sample_list_private_connections():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.ListPrivateConnectionsRequest(
@@ -1852,7 +1919,7 @@ class DatastreamAsyncClient:
                 page_result = client.list_private_connections(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1911,12 +1978,20 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListPrivateConnectionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1934,14 +2009,13 @@ class DatastreamAsyncClient:
         r"""Use this method to delete a private connectivity
         configuration.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_delete_private_connection():
+            async def sample_delete_private_connection():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.DeletePrivateConnectionRequest(
@@ -1953,7 +2027,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1989,9 +2063,6 @@ class DatastreamAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -2025,7 +2096,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -2052,14 +2128,13 @@ class DatastreamAsyncClient:
         r"""Use this method to create a route for a private
         connectivity in a project and location.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_create_route():
+            async def sample_create_route():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 route = datastream_v1alpha1.Route()
@@ -2077,7 +2152,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -2155,7 +2230,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -2183,9 +2263,9 @@ class DatastreamAsyncClient:
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_get_route():
+            async def sample_get_route():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.GetRouteRequest(
@@ -2193,7 +2273,7 @@ class DatastreamAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_route(request=request)
+                response = await client.get_route(request=request)
 
                 # Handle the response
                 print(response)
@@ -2254,7 +2334,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -2271,14 +2356,13 @@ class DatastreamAsyncClient:
         r"""Use this method to list routes created for a private
         connectivity in a project and location.
 
-
         .. code-block:: python
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_list_routes():
+            async def sample_list_routes():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.ListRoutesRequest(
@@ -2289,7 +2373,7 @@ class DatastreamAsyncClient:
                 page_result = client.list_routes(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -2348,12 +2432,20 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListRoutesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -2374,9 +2466,9 @@ class DatastreamAsyncClient:
 
             from google.cloud import datastream_v1alpha1
 
-            def sample_delete_route():
+            async def sample_delete_route():
                 # Create a client
-                client = datastream_v1alpha1.DatastreamClient()
+                client = datastream_v1alpha1.DatastreamAsyncClient()
 
                 # Initialize request argument(s)
                 request = datastream_v1alpha1.DeleteRouteRequest(
@@ -2388,7 +2480,7 @@ class DatastreamAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -2424,9 +2516,6 @@ class DatastreamAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -2460,7 +2549,12 @@ class DatastreamAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
